These are the generic components for framing and serializing data passed
between the different service components. This is especially necessary between
a host environment and an enclave as enclaves may be resource constrained, making
higher level abstractions unavailable.
A highly simplified version of RA-TLS. This performs a Diffie-Hellman
key exchange using a hardcoded cryptographic suits as well as remote
attestation. If successful, a single encrypted message containing an
FMD key is sent and the connection is terminated. This means that
we do not need to maintain a list of active sessions or session ids.