pub struct IndexList(/* private fields */);Implementations
Sourceimpl IndexList
impl IndexList
Sourcepub fn try_from_bytes(bytes: &[u8]) -> Option<Self>
pub fn try_from_bytes(bytes: &[u8]) -> Option<Self>
Try to parse bytes into a list of indices
Sourcepub fn combine(&mut self, other: Self)
pub fn combine(&mut self, other: Self)
Given two index sets, produce a new index set modifying self in-place.
We assume self is synced ahead of other. The intersection of
the indices up to the common block height is kept along with all
indices of self with block height greater than other’s maximum
block height.
Sourcepub fn contains(&self, index: &Index) -> bool
pub fn contains(&self, index: &Index) -> bool
Check if an index is contained in self
Assumes self is sorted.
Sourcepub fn contains_height(&self, height: u64) -> bool
pub fn contains_height(&self, height: u64) -> bool
Check if the index set contains a given height.
Assumes self is sorted.