Connection

Enum Connection 

pub enum Connection {
    Handshake {
        ephemeral_key: EphemeralSecret,
    },
    Initialized {
        shared_key: ChaCha20Poly1305,
    },
}
A simplified, bespoke RA-TLS connection It can be in two possible states:

  • Handshake - initializing session between two parties
  • Initialized - ready for communicating messages securely

Variants



Handshake

Fields

ephemeral_key: EphemeralSecret


Initialized

Fields

shared_key: ChaCha20Poly1305

Implementations

Source

impl Connection

pub fn new(rng: impl CryptoRng + RngCore) -> Self

Create a new connection, which creates and ephemeral key for Diffie-Hellman

pub fn client_send(&self, nonce: u64) -> Result<ClientMsg, RatlsError>

The client side sends its ephemeral public key

pub fn enclave_reply(&self, report: Vec<u8>) -> Result<MsgToHost, RatlsError>

The enclave replies with its Attestation report, which contains its ephemeral public key and a session id.

pub fn initialize(self, pk: PublicKey) -> Result<Self, RatlsError>

Compute the shared ChaCha20 public key for the connection.

pub fn encrypt_msg<T: CryptoRng + RngCore>( &self, payload: &[u8], rng: &mut T, ) -> Result<TlsCiphertext, RatlsError>

Encrypt a message with the session key

pub fn decrypt_msg<T: DeserializeOwned>( &self, msg: &TlsCiphertext, ) -> Result<T, RatlsError>

Decrypt and deserialize message