EnclaveClient

Trait EnclaveClient 

pub trait EnclaveClient {
    type Error: Error + Display;

    // Required method
    fn verify_quote(report: &[u8], nonce: u64) -> Result<[u8; 64], Self::Error>;
}
Logic for clients to verify enclave reports and extract data from them

Required Associated Types

Required Methods

fn verify_quote(report: &[u8], nonce: u64) -> Result<[u8; 64], Self::Error>

Verifies an attestation report and returns the user data if successful. The nonce is a challenge provided by the client to protect against replays.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors