Shared types to be stored in the host databases
Structs
- EncKey
- A wrapper around a ChaCha key
- Encrypted
Response - The response from the enclave for performing FMD for a particular uses
- Index
- Simplified domain type for indexing a Tx on chain
- Index
List