Struct IndexList

pub struct IndexList(/* private fields */);

Implementations

Source

impl IndexList

pub fn try_from_bytes(bytes: &[u8]) -> Option<Self>

Try to parse bytes into a list of indices

pub fn combine(&mut self, other: Self)

Given two index sets, produce a new index set modifying self in-place.

We assume self is synced ahead of other. The intersection of the indices up to the common block height is kept along with all indices of self with block height greater than other’s maximum block height.

pub fn union(&mut self, other: &Self)

Create a union of two index sets

pub fn contains(&self, index: &Index) -> bool

Check if an index is contained in self Assumes self is sorted.

pub fn contains_height(&self, height: u64) -> bool

Check if the index set contains a given height. Assumes self is sorted.

pub fn iter(&self) -> Iter<'_, Index>

Return and iterator of references to the contained indices

pub fn retain<P>(&mut self, pred: P)
where P: FnMut(&Index) -> bool,

Function for filtering out elements in-place